==> igniteui-react-charts-16.16.1.tgz: package/esm5/lib/igr-radial-line-series.js <==
import { __extends } from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialLineSeries } from "./RadialLineSeries";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent radial line series.
*/
var IgrRadialLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRadialLineSeries, _super);
    function IgrRadialLineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialLineSeries.prototype.createImplementation = function () {
        return new RadialLineSeries();
    };
    Object.defineProperty(IgrRadialLineSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialLineSeries.prototype, "isLineOnly", {
        /**
         * Gets whether the current series shows only line shapes.
        */
        get: function () {
            return this.i.d1;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialLineSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.t8;
        },
        set: function (v) {
            this.i.t8 = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    /**
     * When overridden in a derived class, is invoked whenever application code or internal processes
     * call ApplyTemplate.
    
    */
    IgrRadialLineSeries.prototype.onApplyTemplate = function () {
        this.i.ac();
    };
    return IgrRadialLineSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialLineSeries };

==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/igr-radial-line-series.js <==
import { __extends } from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialLineSeries } from "./RadialLineSeries";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent radial line series.
*/
var IgrRadialLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRadialLineSeries, _super);
    function IgrRadialLineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialLineSeries.prototype.createImplementation = function () {
        return new RadialLineSeries();
    };
    Object.defineProperty(IgrRadialLineSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialLineSeries.prototype, "isLineOnly", {
        /**
         * Gets whether the current series shows only line shapes.
        */
        get: function () {
            return this.i.d2;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialLineSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.uc;
        },
        set: function (v) {
            this.i.uc = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    /**
     * When overridden in a derived class, is invoked whenever application code or internal processes
     * call ApplyTemplate.
    
    */
    IgrRadialLineSeries.prototype.onApplyTemplate = function () {
        this.i.ac();
    };
    return IgrRadialLineSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialLineSeries };
